##  Set the Timeline
Begin by estimating how long your initiative is expected to take. This initial timeline helps set expectations and provides a general estimate for the duration of the project.
As your planning progresses, you'll define a more detailed timeline that includes key milestones like the following:
  * Region-specific rollout
  * End of support for a retired application
  * Completion of data migration
  * Go-live for a specific department or business uni


**Note**
Most timeline planning, including adding milestones to your initiatives, takes place in [Step 5: Plan Transformations and Create a Roadmap](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap?locale=en-US&state=PRODUCTION&version=CLOUD "After evaluating which applications are best suited for modernization, it's time to plan your initiatives. This involves documenting your decisions, setting up your transformations, and creating a roadmap."). This step guides you in building a structured timeline that reflects key phases of your transformation.
